summaryrefslogtreecommitdiffstats
path: root/krdc/vnc/rfbproto.c
diff options
context:
space:
mode:
Diffstat (limited to 'krdc/vnc/rfbproto.c')
-rw-r--r--krdc/vnc/rfbproto.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/krdc/vnc/rfbproto.c b/krdc/vnc/rfbproto.c
index 63901a0f..371912a4 100644
--- a/krdc/vnc/rfbproto.c
+++ b/krdc/vnc/rfbproto.c
@@ -159,7 +159,7 @@ ConnectToRFBServer(const char *hostname, int port)
* InitialiseRFBConnection.
*/
-enum InitStatus
+enum InittqStatus
InitialiseRFBConnection()
{
rfbProtocolVersionMsg pv;
@@ -558,7 +558,7 @@ HandleSoftCursorSetImage(rfbSoftCursorSetImage *msg, rfbRectangle *rect)
/* framebuffer must be locked when calling this!!! */
static Bool
-PointerMove(unsigned int x, unsigned int y, unsigned int mask,
+PointerMove(unsigned int x, unsigned int y, unsigned int tqmask,
int ox, int oy, int ow, int oh)
{
int nx, ny, nw, nh;
@@ -585,7 +585,7 @@ PointerMove(unsigned int x, unsigned int y, unsigned int mask,
SyncScreenRegion(nx, ny, nw, nh);
}
- postMouseEvent(cursorX, cursorY, mask);
+ postMouseEvent(cursorX, cursorY, tqmask);
return True;
}
@@ -734,12 +734,12 @@ static void *MakeSoftCursor(int bpp, int cursorWidth, int cursorHeight,
/*********************************************************************
* HandleCursorShape(). Support for XCursor and RichCursor shape
* updates. We emulate cursor operating on the frame buffer (that is
* why we call it "software cursor").
********************************************************************/
-static Bool HandleCursorShape(int xhot, int yhot, int width, int height, CARD32 enc)
+static Bool HandletqCursorShape(int xhot, int yhot, int width, int height, CARD32 enc)
{
int bytesPerPixel;
size_t bytesPerRow, bytesMaskData;
@@ -759,7 +759,7 @@ static Bool HandleCursorShape(int xhot, int yhot, int width, int height, CARD32
if (width * height == 0)
return True;
/* Allocate memory for pixel data and temporary mask data. */
rcSource = malloc(width * height * bytesPerPixel);
if (rcSource == NULL)
@@ -830,7 +830,7 @@ static Bool HandleCursorShape(int xhot, int yhot, int width, int height, CARD32
}
}
/* Read mask data. */
if (!ReadFromRFBServer((char*)rcMask, bytesMaskData)) {
free(rcSource);
@@ -910,9 +910,9 @@ HandleRFBServerMessage()
xc.blue = Swap16IfLE(rgb[2]);
xc.flags = DoRed|DoGreen|DoBlue;
/* Disable colormaps
- lockQt();
+ lockTQt();
XStoreColor(dpy, cmap, &xc);
- unlockQt();
+ unlockTQt();
*/
}
@@ -956,7 +956,7 @@ HandleRFBServerMessage()
if (rect.encoding == rfbEncodingXCursor ||
rect.encoding == rfbEncodingRichCursor) {
- if (!HandleCursorShape(rect.r.x, rect.r.y, rect.r.w, rect.r.h,
+ if (!HandletqCursorShape(rect.r.x, rect.r.y, rect.r.w, rect.r.h,
rect.encoding)) {
return False;
}
@@ -734,12 +734,12 @@ static void *MakeSoftCursor(int bpp, int cursorWidth, int cursorHeight,
/*********************************************************************
- * HandleCursorShape(). Support for XCursor and RichCursor shape
+ * HandletqCursorShape(). Support for XCursor and RichCursor tqshape
* updates. We emulate cursor operating on the frame buffer (that is
* why we call it "software cursor").
@@ -759,7 +759,7 @@ static Bool HandleCursorShape(int xhot, int yhot, int width, int height, CARD32
if (width * height == 0)
return True;
- /* Allocate memory for pixel data and temporary mask data. */
+ /* Allocate memory for pixel data and temporary tqmask data. */
rcSource = malloc(width * height * bytesPerPixel);
if (rcSource == NULL)
@@ -830,7 +830,7 @@ static Bool HandleCursorShape(int xhot, int yhot, int width, int height, CARD32
}
}
- /* Read mask data. */
+ /* Read tqmask data. */
if (!ReadFromRFBServer((char*)rcMask, bytesMaskData)) {
free(rcSource);